@@ -239,7 +239,7 @@ async def on_message(message):
                             dir_path = os.path.dirname(os.path.realpath(__file__))
                             link_given = True
                             song_name = random.randint(1, 1000)
-                            subprocess.call(f"youtibe-dl --extract-audio --audio-format mp3 -o {dir_path}/{song_name}.mp3 {message.content.split(' ')}", shell=True)
+                            subprocess.call(f"youtibe-dl --extract-audio --audio-format mp3 -o {dir_path}\{song_name}.mp3 {message.content.split(' ')[1]}", shell=True)
                     channel_to_connnect_to = message.author.voice.channel
                     voice_object = await channel_to_connnect_to.connect()
                     if command_dict[c]["source_to_play"] == None:
